@@ -1,5 +1,4 @@
-from .node import Node
-from .tree import Tree
+from .tree import Tree, Node
 from .interactive import TreeBasedObj
 
 __all__ = ["Tree", "Node", "TreeBasedObj"]
